@@ -5,11 +5,10 @@
 # 2024 Translated from MATLAB to Python by U.A. Canbolat <utku.canbolat@fau.de>
 
 import sys
-sys.path.append('/home/vas/Desktop/Utku_Code_Review/CLUMP_Python/')
 
-from CLUMP.GenerateClump_Ferellec_McDowell import GenerateClump_Ferellec_McDowell
+from CLUMP import GenerateClump_Ferellec_McDowell
 import sys
-sys.path.append('../')
+sys.path.append('../../')
 
 inputGeom = 'ParticleGeometries/Torus.stl'
 dmin = 0.1
